@@ -1,12 +1,12 @@
 package WordList::HTTP::UserAgentString::PERLANCAR;
 
-our $DATE = '2019-06-11'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-06-17'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("longest_word_len",113,"avg_word_len",89.25,"num_words",4,"num_words_contains_nonword_chars",4,"shortest_word_len",68,"num_words_contains_whitespace",4,"num_words_contains_unicode",0); # STATS
+our %STATS = ("num_words_contains_unicode",0,"avg_word_len",95.6666666666667,"num_words",6,"longest_word_len",113,"shortest_word_len",68,"num_words_contains_whitespace",6,"num_words_contains_nonword_chars",6); # STATS
 
 1;
 # ABSTRACT: A selection of some HTTP User-Agent strings
@@ -21,7 +21,7 @@ WordList::HTTP::UserAgentString::PERLANCAR - A selection of some HTTP User-Agent
 
 =head1 VERSION
 
-This document describes version 0.002 of WordList::HTTP::UserAgentString::PERLANCAR (from Perl distribution WordList-HTTP-UserAgentString-PERLANCAR), released on 2019-06-11.
+This document describes version 0.003 of WordList::HTTP::UserAgentString::PERLANCAR (from Perl distribution WordList-HTTP-UserAgentString-PERLANCAR), released on 2019-06-17.
 
 =head1 SYNOPSIS
 
@@ -48,17 +48,17 @@ My selection: recent Firefox (Linux & Windows), recent Chrome (Linux & Windows).
 
 =head1 STATISTICS
 
- +----------------------------------+-------+
- | key                              | value |
- +----------------------------------+-------+
- | avg_word_len                     | 89.25 |
- | longest_word_len                 | 113   |
- | num_words                        | 4     |
- | num_words_contains_nonword_chars | 4     |
- | num_words_contains_unicode       | 0     |
- | num_words_contains_whitespace    | 4     |
- | shortest_word_len                | 68    |
- +----------------------------------+-------+
+ +----------------------------------+------------------+
+ | key                              | value            |
+ +----------------------------------+------------------+
+ | avg_word_len                     | 95.6666666666667 |
+ | longest_word_len                 | 113              |
+ | num_words                        | 6                |
+ | num_words_contains_nonword_chars | 6                |
+ | num_words_contains_unicode       | 0                |
+ | num_words_contains_whitespace    | 6                |
+ | shortest_word_len                | 68               |
+ +----------------------------------+------------------+
 
 The statistics is available in the C<%STATS> package variable.
 
@@ -94,5 +94,7 @@ the same terms as the Perl 5 programming language system itself.
 __DATA__
 Mozilla/5.0 (Windows NT 6.1; WOW64; rv:67.0) Gecko/20100101 Firefox/67.0
 Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36
+Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36
 Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36
+Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36
 Mozilla/5.0 (X11; Linux x86_64; rv:67.0) Gecko/20100101 Firefox/67.0
